==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/id.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Penyimpanan tidak tersedia",
    "Storage invalid" : "Penyimpanan tidak sah",
    "Unknown error" : "Kesalahan tidak diketahui",
    "Unable to set upload directory." : "Tidak dapat mengatur folder unggah",
    "Invalid Token" : "Token tidak sah",
    "No file was uploaded. Unknown error" : "Tidak ada berkas yang diunggah. Kesalahan tidak dikenal.",
    "There is no error, the file uploaded with success" : "Tidak ada kesalahan, berkas sukses diunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Berkas yang diunggah melampaui direktif upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The uploaded file was only partially uploaded" : "Berkas hanya diunggah sebagian",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Failed to write to disk" : "Gagal menulis ke disk",
    "Not enough storage available" : "Ruang penyimpanan tidak mencukupi",
    "The target folder has been moved or deleted." : "Folder tujuan telah dipindahkan atau dihapus.",
    "Upload failed. Could not find uploaded file" : "Unggah gagal. Tidak menemukan berkas yang akan diunggah",
    "Upload failed. Could not get file info." : "Unggah gagal. Tidak mendapatkan informasi berkas.",
    "Invalid directory." : "Direktori tidak valid.",
    "Files" : "Berkas",
    "All files" : "Semua berkas",
    "Favorites" : "Favorit",
    "Home" : "Rumah",
    "Close" : "Tutup",
    "Upload cancelled." : "Pengunggahan dibatalkan.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tidak dapat mengunggah {filename} karena ini sebuah direktori atau memiliki ukuran 0 byte",
    "Total file size {size1} exceeds upload limit {size2}" : "Jumlah ukuran berkas {size1} melampaui batas unggah {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ruang bebas tidak mencukupi, Anda mengunggah {size1} tetapi hanya {size2} yang tersisa",
    "Could not get result from server." : "Tidak mendapatkan hasil dari server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Berkas sedang diunggah. Meninggalkan halaman ini akan membatalkan proses.",
    "Actions" : "Tindakan",
    "Download" : "Unduh",
    "Rename" : "Ubah nama",
    "Delete" : "Hapus",
    "Disconnect storage" : "Memutuskan penyimpaan",
    "Unshare" : "Batalkan berbagi",
    "Details" : "Rincian",
    "Select" : "Pilih",
    "Pending" : "Tertunda",
    "Unable to determine date" : "Tidak dapat menentukan tanggal",
    "This operation is forbidden" : "Operasi ini dilarang",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktori ini tidak tersedia, silakan periksa log atau hubungi kontak",
    "No entries in this folder match '{filter}'" : "Tidak ada entri di folder ini yang cocok dengan '{filter}'",
    "Name" : "Nama",
    "Size" : "Ukuran",
    "Modified" : "Dimodifikasi",
    "_%n folder_::_%n folders_" : ["%n folder"],
    "_%n file_::_%n files_" : ["%n berkas"],
    "{dirs} and {files}" : "{dirs} dan {files}",
    "You don’t have permission to upload or create files here" : "Anda tidak memiliki akses untuk mengunggah atau membuat berkas disini",
    "_Uploading %n file_::_Uploading %n files_" : ["Mengunggah %n berkas"],
    "New" : "Baru",
    "\"{name}\" is an invalid file name." : "\"{name}\" adalah nama berkas yang tidak sah.",
    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Penyimpanan {owner} penuh, berkas tidak dapat diperbarui atau disinkronisasikan lagi!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ruang penyimpanan Anda penuh, berkas tidak dapat diperbarui atau disinkronkan lagi!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Penyimpanan {owner} hampir penuh ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ruang penyimpanan hampir penuh ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["cocok dengan '{filter}'"],
    "Path" : "Jalur",
    "_%n byte_::_%n bytes_" : ["%n byte"],
    "Favorited" : "Difavoritkan",
    "Favorite" : "Favorit",
    "Folder" : "Folder",
    "New folder" : "Map baru",
    "{newname} already exists" : "{newname} sudah ada",
    "Upload" : "Unggah",
    "An error occurred while trying to update the tags" : "Terjadi kesalahan saat mencoba untuk memperbarui label",
    "A new file or folder has been <strong>created</strong>" : "Sebuah berkas atau folder baru telah <strong>dibuat</strong>",
    "A file or folder has been <strong>changed</strong>" : "Sebuah berkas atau folder telah <strong>diubah</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Batas notifikasi tentang pembuatan dan perubahan <strong>berkas favorit</strong> Anda <em>(Hanya stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Sebuah berkas atau folder telah <strong>dihapus</strong>",
    "A file or folder has been <strong>restored</strong>" : "Sebuah berkas atau folder telah <strong>dipulihkan</strong>",
    "You created %1$s" : "Anda membuat %1$s",
    "%2$s created %1$s" : "%2$s membuat %1$s",
    "%1$s was created in a public folder" : "%1$s telah dibuat di folder publik",
    "You changed %1$s" : "Anda mengubah %1$s",
    "%2$s changed %1$s" : "%2$s mengubah %1$s",
    "You deleted %1$s" : "Anda menghapus %1$s",
    "%2$s deleted %1$s" : "%2$s menghapus %1$s",
    "You restored %1$s" : "Anda memulihkan %1$s",
    "%2$s restored %1$s" : "%2$s memulihkan %1$s",
    "Changed by %2$s" : "Diubah oleh %2$s",
    "Deleted by %2$s" : "Dihapus oleh %2$s",
    "Restored by %2$s" : "Dipulihkan oleh %2$s",
    "Upload (max. %s)" : "Unggah (maks. %s)",
    "File handling" : "Penanganan berkas",
    "Maximum upload size" : "Ukuran pengunggahan maksimum",
    "max. possible: " : "Kemungkinan maks.:",
    "Save" : "Simpan",
    "Settings" : "Pengaturan",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Gunakan alamat ini untuk <a href=\"%s\" target=\"_blank\">mengakses Berkas via WebDAV</a>",
    "Cancel upload" : "Batal unggah",
    "No files in here" : "Tidak ada berkas disini",
    "Upload some content or sync with your devices!" : "Unggah beberapa konten dan sinkronisasikan dengan perangkat Anda!",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Select all" : "Pilih Semua",
    "Upload too large" : "Yang diunggah terlalu besar",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Berkas yang dicoba untuk diunggah melebihi ukuran maksimum pengunggahan berkas di server ini.",
    "No favorites" : "Tidak ada favorit",
    "Files and folders you mark as favorite will show up here" : "Berkas dan folder yang Anda tandai sebagai favorit akan ditampilkan disini.",
    "Text file" : "Berkas teks",
    "New text file.txt" : "Teks baru file.txt",
    "Changed by %2$s" : "Diubah oleh %2$s",
    "Deleted by %2$s" : "Dihapus oleh %2$s",
    "Restored by %2$s" : "Dipulihkan oleh %2$s",
    "You changed %1$s" : "Anda mengubah %1$s",
    "You created %1$s" : "Anda membuat %1$s",
    "You deleted %1$s" : "Anda menghapus %1$s",
    "You restored %1$s" : "Anda memulihkan %1$s"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.4.tgz: owncloud/apps/files/l10n/id.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Penyimpanan tidak tersedia",
    "Storage invalid" : "Penyimpanan tidak sah",
    "Unknown error" : "Kesalahan tidak diketahui",
    "Unable to set upload directory." : "Tidak dapat mengatur folder unggah",
    "Invalid Token" : "Token tidak sah",
    "No file was uploaded. Unknown error" : "Tidak ada berkas yang diunggah. Kesalahan tidak dikenal.",
    "There is no error, the file uploaded with success" : "Tidak ada kesalahan, berkas sukses diunggah",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Berkas yang diunggah melampaui direktif upload_max_filesize pada php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Berkas yang diunggah melampaui direktif MAX_FILE_SIZE yang ditentukan dalam formulir HTML.",
    "The uploaded file was only partially uploaded" : "Berkas hanya diunggah sebagian",
    "No file was uploaded" : "Tidak ada berkas yang diunggah",
    "Missing a temporary folder" : "Folder sementara tidak ada",
    "Failed to write to disk" : "Gagal menulis ke disk",
    "Not enough storage available" : "Ruang penyimpanan tidak mencukupi",
    "The target folder has been moved or deleted." : "Folder tujuan telah dipindahkan atau dihapus.",
    "Upload failed. Could not find uploaded file" : "Unggah gagal. Tidak menemukan berkas yang akan diunggah",
    "Upload failed. Could not get file info." : "Unggah gagal. Tidak mendapatkan informasi berkas.",
    "Invalid directory." : "Direktori tidak valid.",
    "Files" : "Berkas",
    "All files" : "Semua berkas",
    "Home" : "Rumah",
    "Close" : "Tutup",
    "Favorites" : "Favorit",
    "Upload cancelled." : "Pengunggahan dibatalkan.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Tidak dapat mengunggah {filename} karena ini sebuah direktori atau memiliki ukuran 0 byte",
    "Total file size {size1} exceeds upload limit {size2}" : "Jumlah ukuran berkas {size1} melampaui batas unggah {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ruang bebas tidak mencukupi, Anda mengunggah {size1} tetapi hanya {size2} yang tersisa",
    "Could not get result from server." : "Tidak mendapatkan hasil dari server.",
    "Uploading..." : "Mengunggah...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Berkas sedang diunggah. Meninggalkan halaman ini akan membatalkan proses.",
    "Actions" : "Tindakan",
    "Download" : "Unduh",
    "Rename" : "Ubah nama",
    "Delete" : "Hapus",
    "Disconnect storage" : "Memutuskan penyimpaan",
    "Unshare" : "Batalkan berbagi",
    "Details" : "Rincian",
    "Select" : "Pilih",
    "Pending" : "Tertunda",
    "Unable to determine date" : "Tidak dapat menentukan tanggal",
    "This operation is forbidden" : "Operasi ini dilarang",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktori ini tidak tersedia, silakan periksa log atau hubungi kontak",
    "No entries in this folder match '{filter}'" : "Tidak ada entri di folder ini yang cocok dengan '{filter}'",
    "Name" : "Nama",
    "Size" : "Ukuran",
    "Modified" : "Dimodifikasi",
    "_%n folder_::_%n folders_" : ["%n folder"],
    "_%n file_::_%n files_" : ["%n berkas"],
    "{dirs} and {files}" : "{dirs} dan {files}",
    "You don’t have permission to upload or create files here" : "Anda tidak memiliki akses untuk mengunggah atau membuat berkas disini",
    "_Uploading %n file_::_Uploading %n files_" : ["Mengunggah %n berkas"],
    "New" : "Baru",
    "\"{name}\" is an invalid file name." : "\"{name}\" adalah nama berkas yang tidak sah.",
    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Penyimpanan {owner} penuh, berkas tidak dapat diperbarui atau disinkronisasikan lagi!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ruang penyimpanan Anda penuh, berkas tidak dapat diperbarui atau disinkronkan lagi!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Penyimpanan {owner} hampir penuh ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ruang penyimpanan hampir penuh ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["cocok dengan '{filter}'"],
    "Path" : "Jalur",
    "_%n byte_::_%n bytes_" : ["%n byte"],
    "Favorited" : "Difavoritkan",
    "Favorite" : "Favorit",
    "Folder" : "Folder",
    "New folder" : "Map baru",
    "{newname} already exists" : "{newname} sudah ada",
    "Upload" : "Unggah",
    "An error occurred while trying to update the tags" : "Terjadi kesalahan saat mencoba untuk memperbarui label",
    "A new file or folder has been <strong>created</strong>" : "Sebuah berkas atau folder baru telah <strong>dibuat</strong>",
    "A file or folder has been <strong>changed</strong>" : "Sebuah berkas atau folder telah <strong>diubah</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Batas notifikasi tentang pembuatan dan perubahan <strong>berkas favorit</strong> Anda <em>(Hanya stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Sebuah berkas atau folder telah <strong>dihapus</strong>",
    "A file or folder has been <strong>restored</strong>" : "Sebuah berkas atau folder telah <strong>dipulihkan</strong>",
    "You created %1$s" : "Anda membuat %1$s",
    "%2$s created %1$s" : "%2$s membuat %1$s",
    "%1$s was created in a public folder" : "%1$s telah dibuat di folder publik",
    "You changed %1$s" : "Anda mengubah %1$s",
    "%2$s changed %1$s" : "%2$s mengubah %1$s",
    "You deleted %1$s" : "Anda menghapus %1$s",
    "%2$s deleted %1$s" : "%2$s menghapus %1$s",
    "You restored %1$s" : "Anda memulihkan %1$s",
    "%2$s restored %1$s" : "%2$s memulihkan %1$s",
    "Changed by %2$s" : "Diubah oleh %2$s",
    "Deleted by %2$s" : "Dihapus oleh %2$s",
    "Restored by %2$s" : "Dipulihkan oleh %2$s",
    "Upload (max. %s)" : "Unggah (maks. %s)",
    "File handling" : "Penanganan berkas",
    "Maximum upload size" : "Ukuran pengunggahan maksimum",
    "max. possible: " : "Kemungkinan maks.:",
    "Save" : "Simpan",
    "Settings" : "Pengaturan",
    "WebDAV" : "WebDAV",
    "No files in here" : "Tidak ada berkas disini",
    "Upload some content or sync with your devices!" : "Unggah beberapa konten dan sinkronisasikan dengan perangkat Anda!",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Select all" : "Pilih Semua",
    "Upload too large" : "Yang diunggah terlalu besar",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Berkas yang dicoba untuk diunggah melebihi ukuran maksimum pengunggahan berkas di server ini.",
    "No favorites" : "Tidak ada favorit",
    "Files and folders you mark as favorite will show up here" : "Berkas dan folder yang Anda tandai sebagai favorit akan ditampilkan disini.",
    "Text file" : "Berkas teks",
    "New text file.txt" : "Teks baru file.txt"
},
"nplurals=1; plural=0;");
